@@ -30,7 +30,7 @@ class SegmentsClient:
         self.s3_session.mount('http://', adapter)
         self.s3_session.mount('https://', adapter)
 
-        r = self.get('/api_status/?lib_version=0.53')
+        r = self.get('/api_status/?lib_version=0.56')
         if r.status_code == 200:
             print('Initialized successfully.')
         elif r.status_code == 426:
@@ -70,7 +70,7 @@ class SegmentsClient:
         r = self.get('/datasets/{}/'.format(dataset_identifier))
         return r.json()
 
-    def add_dataset(self, name, description='', task_type='segmentation-bitmap', task_attributes=None, category='other', public=False, readme=''):
+    def add_dataset(self, name, description='', task_type='segmentation-bitmap', task_attributes=None, category='other', public=False, readme='', enable_skip_labeling=True, enable_skip_reviewing=False, enable_ratings=False):
         """Add a dataset.
 
         Args:
@@ -81,6 +81,9 @@ class SegmentsClient:
             category (str, optional): The dataset category. Defaults to 'other'.
             public (bool, optional): The dataset visibility. Defaults to False.
             readme (str, optional): The dataset readme. Defaults to ''.
+            enable_skip_labeling (bool, optional): Enable the skip button in the labeling workflow. Defaults to True.
+            enable_skip_reviewing (bool, optional): Enable the skip button in the reviewing workflow. Defaults to False.
+            enable_ratings: Enable star-ratings for labeled images. Defaults to False.
 
         Returns:
             dict: a dictionary representing the newly created dataset.
@@ -105,12 +108,15 @@ class SegmentsClient:
             'category': category,
             'public': public,
             'readme': readme,
+            'enable_skip_labeling': enable_skip_labeling,
+            'enable_skip_reviewing': enable_skip_reviewing,
+            'enable_ratings': enable_ratings,
             'data_type': 'IMAGE'
         }
         r = self.post('/user/datasets/', payload)
         return r.json()
 
-    def update_dataset(self, dataset_identifier, description=None, task_type=None, task_attributes=None, category=None, public=None, readme=None):
+    def update_dataset(self, dataset_identifier, description=None, task_type=None, task_attributes=None, category=None, public=None, readme=None, enable_skip_labeling=None, enable_skip_reviewing=None, enable_ratings=None):
         """Update a dataset.
 
         Args:
@@ -121,6 +127,9 @@ class SegmentsClient:
             category (str, optional): The dataset category.
             public (bool, optional): The dataset visibility.
             readme (str, optional): The dataset readme.
+            enable_skip_labeling (bool, optional): Enable the skip button in the labeling workflow.
+            enable_skip_reviewing (bool, optional): Enable the skip button in the reviewing workflow.
+            enable_ratings: Enable star-ratings for labeled images.
 
         Returns:
             dict: a dictionary representing the updated dataset.
@@ -146,6 +155,15 @@ class SegmentsClient:
         if readme is not None:
             payload['readme'] = readme
 
+        if enable_skip_labeling is not None:
+            payload['enable_skip_labeling'] = enable_skip_labeling
+
+        if enable_skip_reviewing is not None:
+            payload['enable_skip_reviewing'] = enable_skip_reviewing
+
+        if enable_ratings is not None:
+            payload['enable_ratings'] = enable_ratings
+
         r = self.patch('/datasets/{}/'.format(dataset_identifier), payload)
         print('Updated ' + dataset_identifier)
         return r.json()
@@ -181,11 +199,16 @@ class SegmentsClient:
     ###########
     # Samples #
     ###########
-    def get_samples(self, dataset_identifier, per_page=1000, page=1):
+    def get_samples(self, dataset_identifier, name=None, label_status=None, metadata=None, sort='name', direction='asc', per_page=1000, page=1):
         """Get the samples in a dataset.
 
         Args:
             dataset_identifier (str): The dataset identifier, consisting of the name of the dataset owner followed by the name of the dataset itself. Example: jane/flowers.
+            name (str, optional): Name to filter by. Defaults to None (no filtering).
+            label_status (list, optional): List of label statuses to filter by. Defaults to None (no filtering).
+            metadata (list, optional): List of 'key:value' metadata attributes to filter by. Defaults to None (no filtering).
+            sort (str, optional): What to sort results by. One of 'name', 'created', 'priority'. Defaults to 'name'.
+            direction (str, optional): Sorting direction. One of 'asc' (ascending) or 'desc' (descending). Defaults to 'asc'.
             per_page (int, optional): Pagination parameter indicating the maximum number of samples to return. Defaults to 1000.
             page (int, optional): Pagination parameter indicating the page to return. Defaults to 1.
 
@@ -193,8 +216,42 @@ class SegmentsClient:
             list: a list of dictionaries representing the samples.
         """
 
-        r = self.get('/datasets/{}/samples/?per_page={}&page={}'.format(dataset_identifier, per_page, page))
-        return r.json()
+        # pagination
+        query_string = '?per_page={}&page={}'.format(per_page, page)
+
+        # filter by name
+        if name is not None:
+            query_string += '&name__contains={}'.format(name)
+
+        # filter by metadata
+        if metadata is not None:
+            if isinstance(metadata, str):
+                metadata = [metadata]
+            query_string += '&filters={}'.format(','.join(metadata))
+
+        # filter by label status
+        if label_status is not None:
+            if isinstance(label_status, str):
+                label_status = [label_status]
+            assert isinstance(label_status, list)
+            label_status = [status.upper() for status in label_status]
+            query_string += '&labelset=ground-truth&label_status={}'.format(','.join(label_status))
+
+        # sorting
+        sort_dict = { 'name': 'name', 'created': 'created_at', 'priority': 'priority' }
+        assert sort in sort_dict
+        assert direction in ['asc', 'desc']
+        if sort != 'name':            
+            direction_str = '' if direction == 'asc' else '-'
+            sort_str = sort_dict[sort]
+            query_string += '&sort={}{}'.format(direction_str, sort_str)
+
+        r = self.get('/datasets/{}/samples/{}'.format(dataset_identifier, query_string))
+        results = r.json()
+
+        for result in results:
+            result.pop('label', None)
+        return results
 
     def get_sample(self, uuid, labelset=None):
         """Get a sample.
@@ -377,6 +434,33 @@ class SegmentsClient:
     #############
     # Labelsets #
     #############
+    def get_labelsets(self, dataset_identifier):
+        """Get the labelsets in a dataset.
+
+        Args:
+            dataset_identifier (str): The dataset identifier, consisting of the name of the dataset owner followed by the name of the dataset itself. Example: jane/flowers.
+
+        Returns:
+            list: a list of dictionaries representing the labelsets.
+        """
+
+        r = self.get('/datasets/{}/labelsets/'.format(dataset_identifier))
+        return r.json()
+
+    def get_labelset(self, dataset_identifier, name):
+        """Get a labelset.
+
+        Args:
+            dataset_identifier (str): The dataset identifier, consisting of the name of the dataset owner followed by the name of the dataset itself. Example: jane/flowers.
+            name (str): The name of the labelset.
+
+        Returns:
+            dict: a dictionary representing the labelset.
+        """
+
+        r = self.get('/datasets/{}/labelsets/{}/'.format(dataset_identifier, name))
+        return r.json()
+
     def add_labelset(self, dataset_identifier, name, description=''):
         """Add a labelset to a dataset.
 
@@ -397,6 +481,15 @@ class SegmentsClient:
         r = self.post('/datasets/{}/labelsets/'.format(dataset_identifier), payload)
         return r.json()
 
+    def delete_labelset(self, dataset_identifier, name):
+        """Delete a labelset.
+
+        Args:
+            dataset_identifier (str): The dataset identifier, consisting of the name of the dataset owner followed by the name of the dataset itself. Example: jane/flowers.
+            name (str): The name of the labelset.
+        """
+
+        r = self.delete('/datasets/{}/labelsets/{}/'.format(dataset_identifier, name))
 
     ############
     # Releases #
